backgrid-filter
===============
[![Build Status](https://travis-ci.org/wyuenho/backgrid-filter.png?branch=master)](https://travis-ci.org/wyuenho/backgrid-filter)

Dependencies
============
[lunr >= 0.2.1](http://lunrjs.com) (LunrFilter)

Usage
=====
See the [Filter](http://backgridjs.com/ref/extensions/filter.html) section in
the documentation.
